%ifnarch %{ocaml_native_compiler}
%global debug_package %{nil}
%endif

%define base_name	lablgl
%define srcname		lablGL

%define distname	%{base_name}-%{version}.tar.gz
%define distdir		%{base_name}-%{version}

Name:		ocaml-%{base_name}
Version:	1.07
Release:	%mkrel 1
Summary:	OpenGL interface for OCaml
License:	BSD
Group:		Development/OCaml
URL:		http://wwwfun.kurims.kyoto-u.ac.jp/soft/olabl/lablgl.html
Source0:	https://github.com/garrigue/lablgl/archive/v%{version}/%{name}-%{version}.tar.gz
# from Fedora
# Fix a use-after-free bug
# https://github.com/garrigue/lablgl/pull/5
Patch:		0001-Avoid-possible-use-after-free-in-Togl.patch
# Fix a build error with the Modern C initiative
# https://github.com/garrigue/lablgl/pull/6
Patch:		0002-Fix-mismatched-pointer-types-for-GCC-14.patch
# https://github.com/garrigue/lablgl/pull/11
Patch:		0003-Add-a-gitignore-file-to-ignore-various-generated-fil.patch
# Adapt to OCaml 5
# https://github.com/garrigue/lablgl/pull/10
Patch:		0004-Update-Tk-code-for-OCaml-5.patch
# Fix for Tcl/Tk 9.0
# https://github.com/garrigue/lablgl/pull/12
Source10:	0005-Togl-Remove-useless-definition-of-NULL.patch
Source11:	0006-Togl-Remove-use-of-some-Tcl-Tk-macros.patch
Source12:	0007-Togl-Pass-object-style-parameters-to-Tk_ConfigureWid.patch
Source13:	0008-Togl-Replace-Tk_-functions-with-new-Tcl_-equivalents.patch
BuildRequires:	ocaml >= 4.14
BuildRequires:	ocaml-findlib >= 1.2.1
BuildRequires:	ocaml-camlp-streams-devel
BuildRequires:	ocaml-compiler-libs
BuildRequires:	ocaml-labltk-devel
BuildRequires:	ocaml-rpm-macros
BuildRequires:	pkgconfig(tcl)
BuildRequires:	pkgconfig(tk)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(freeglut)
BuildRequires:	pkgconfig(xmu)
Requires:	ocaml-labltk

%package devel
Summary:	OpenGL interface for OCaml
Group:		Development/OCaml
Requires:	%{name} = %{version}-%{release}
Requires:	ocaml-labltk-devel%{?_isa}
Requires:	libxmu-devel
Requires:	mesaglu-devel
Requires:	freeglut-devel

%description 
LablGL is is an OCaml interface to OpenGL. Support is included for
use with both Glut (standalone) and LablTk.

%description -n %{name}-devel
The %{name}-devel package contains libraries and signature files for
developing applications that use %{name}.

%prep
%autosetup -p1 -n %{distdir}

cat > Makefile.config <<EOF
BINDIR = %{_bindir}
XINCLUDES = -I%{_prefix}/X11R6/include
XLIBS = -lXext -lXmu -lX11
TKINCLUDES = -I%{_includedir}
TKLIBS = $(pkg-config --libs tk)
GLINCLUDES =
GLLIBS = -lGL -lGLU
GLUTLIBS = -lglut
RANLIB = :
LIBDIR = %{_libdir}/ocaml
DLLDIR = %{_libdir}/ocaml/stublibs
INSTALLDIR = %{_libdir}/ocaml/lablGL
TOGLDIR=Togl
COPTS = %{build_cflags}
EOF

# Prepare the examples for inclusion in the docs
mkdir -p examples/LablGlut examples/Togl
cp -a LablGlut/examples examples/LablGlut
cp -a Togl/examples examples/Togl

# Fix the version number in META
sed -i.orig 's/1\.05/%{version}/' META
touch -r META.orig META

# Build with debuginfo
sed -i 's/\$(CAMLC)/& -g/;s/\$(CAMLOPT)/& -g/;s/ocamlmklib/& -g/' Makefile.common
sed -i 's/ocamlmktop/& -g/' LablGlut/src/Makefile Togl/src/Makefile

%build
# Parallel builds don't work.
unset MAKEFLAGS
make all \
%ifarch %{ocaml_native_compiler}
opt
%endif

%install
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_libdir}/ocaml/lablGL
mkdir -p %{buildroot}%{_libdir}/ocaml/stublibs
make \
   BINDIR=%{buildroot}%{_bindir}\
   INSTALLDIR=%{buildroot}%{_libdir}/ocaml/lablGL\
   DLLDIR=%{buildroot}%{_libdir}/ocaml/stublibs\
   install

rm -f %{buildroot}%{_libdir}/ocaml/lablGL/*.ml

# Install package META.
cp -p META %{buildroot}%{_libdir}/ocaml/lablGL/

%ocaml_files

%files -f .ofiles
%doc README
%license COPYRIGHT

%files devel -f .ofiles-devel
%doc CHANGES README examples/LablGlut examples/Togl
%license COPYRIGHT


%changelog
* Sat Jun 21 2025 daviddavid <daviddavid> 1.07-1.mga10
+ Revision: 2193613
- rebuild for ocaml 5.3.0
+ papoteur <papoteur>
- new version 1.07
- include 2 patches from Fedora

* Thu May 19 2022 pterjan <pterjan> 1.06-8.mga9
+ Revision: 1858899
- Rebuild for OCaml 4.14

* Wed Mar 30 2022 umeabot <umeabot> 1.06-7.mga9
+ Revision: 1835654
- Mageia 9 Mass Rebuild

* Tue Oct 12 2021 tv <tv> 1.06-6.mga9
+ Revision: 1750802
- Rebuild for ocaml 4.13.1

* Wed Mar 03 2021 tv <tv> 1.06-5.mga9
+ Revision: 1696721
- Remove self META file (RHBZ#1806040)

* Sun Jan 10 2021 pterjan <pterjan> 1.06-4.mga8
+ Revision: 1670464
- Rebuild to generate ocamlx provides

* Fri Feb 28 2020 umeabot <umeabot> 1.06-3.mga8
+ Revision: 1551360
- Rebuild for ocaml 4.10.0 final

* Wed Feb 19 2020 umeabot <umeabot> 1.06-2.mga8
+ Revision: 1544538
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 tv <tv> 1.06-1.mga8
+ Revision: 1483195
- new release + rebuild for ocaml-4.10

* Tue Oct 23 2018 pterjan <pterjan> 1.05-12.mga7
+ Revision: 1324400
- Rebuild for ocaml 4.07.1
+ tv <tv>
- rebuild for ocaml 4.07

* Sun Sep 23 2018 umeabot <umeabot> 1.05-10.mga7
+ Revision: 1299884
- Mageia 7 Mass Rebuild

* Sat Nov 25 2017 tv <tv> 1.05-9.mga7
+ Revision: 1179147
- rebuild for new ocaml

* Thu Nov 24 2016 neoclust <neoclust> 1.05-8.mga6
+ Revision: 1069807
- Rebuild against fixed ocaml

* Mon Sep 26 2016 pterjan <pterjan> 1.05-7.mga6
+ Revision: 1056397
- Rebuild for fix in ocaml

* Mon Feb 01 2016 pterjan <pterjan> 1.05-6.mga6
+ Revision: 930654
- Fix BuildRequires
- Rebuild for new ocaml

* Mon Oct 05 2015 eatdirt <eatdirt> 1.05-5.mga6
+ Revision: 886267
- Rebuild for new tcl8.6

* Wed Oct 15 2014 umeabot <umeabot> 1.05-4.mga5
+ Revision: 744311
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.05-3.mga5
+ Revision: 683054
- Mageia 5 Mass Rebuild

* Mon Oct 21 2013 umeabot <umeabot> 1.05-2.mga4
+ Revision: 539202
- Mageia 4 Mass Rebuild

* Fri Oct 04 2013 malo <malo> 1.05-1.mga4
+ Revision: 491598
- new version 1.05

* Sat Sep 07 2013 blue_prawn <blue_prawn> 1.04-17.mga4
+ Revision: 475774
- rebuild for ocaml-4.01.0

* Sun Jan 13 2013 umeabot <umeabot> 1.04-16.mga3
+ Revision: 361417
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 27 2012 pterjan <pterjan> 1.04-15.mga3
+ Revision: 335562
- Workaround new rpm use of dirname macro

* Thu Oct 18 2012 malo <malo> 1.04-14.mga3
+ Revision: 308022
- rebuild for ocaml-4.0.1

* Tue Oct 02 2012 blue_prawn <blue_prawn> 1.04-13.mga3
+ Revision: 302027
- build requires ocaml-compiler-libs
- build requires ocaml-compiler
- rebuild for ocaml-4.00.0
- rebuild for ocaml-4.00.0

* Sat Sep 29 2012 blue_prawn <blue_prawn> 1.04-11.mga3
+ Revision: 300407
- new rpm group for ocaml

* Mon Dec 12 2011 malo <malo> 1.04-10.mga2
+ Revision: 180816
- removing spurious requires

* Mon Dec 12 2011 malo <malo> 1.04-9.mga2
+ Revision: 180806
- missing Requires to ocaml-labltk
- fixed META file with lablGL dir name
- spec clean-up

* Thu Nov 17 2011 malo <malo> 1.04-8.mga2
+ Revision: 168369
- fix description
- fixing path in META

* Sun Oct 02 2011 shlomif <shlomif> 1.04-7.mga2
+ Revision: 151041
- New version - thanks to Malo.

* Sat Sep 24 2011 fwang <fwang> 1.04-0.20081204.6.mga2
+ Revision: 147200
- br xmu
- br xmu
- fix tk header location
- use freeglut

* Tue Feb 22 2011 mikala <mikala> 1.04-0.20081204.6.mga1
+ Revision: 56465
- Remove BuildRoot
- Remove X11-devel BR
- Remove unused use of %%exclude
- imported package ocaml-lablgl


* Mon Aug 16 2010 Florent Monnier <blue_prawn@mandriva.org> 1.04-0.20081204.6mdv2011.0
+ Revision: 570543
- corrected group

* Mon Jan 25 2010 Guillaume Rousse <guillomovitch@mandriva.org> 1.04-0.20081204.6mdv2010.1
+ Revision: 496366
- rebuild

* Sat Jun 27 2009 Guillaume Rousse <guillomovitch@mandriva.org> 1.04-0.20081204.5mdv2010.0
+ Revision: 389928
- rebuild

  + Florent Monnier <blue_prawn@mandriva.org>
    - remove doubles

* Mon Dec 29 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1.04-0.20081204.4mdv2009.1
+ Revision: 321213
- install in %%{_libdir}/ocaml/lablGL instead of %%{_libdir}/ocaml/lablgl
- ship META file
- ship missing binaries

* Mon Dec 29 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1.04-0.20081204.3mdv2009.1
+ Revision: 320757
- move non-devel files in main package
- don't ship ml sources
- site-lib hierarch doesn't exist anymore

* Tue Dec 09 2008 Pixel <pixel@mandriva.com> 1.04-0.20081204.2mdv2009.1
+ Revision: 312227
- rebuild

* Sat Dec 06 2008 Adam Williamson <awilliamson@mandriva.org> 1.04-0.20081204.1mdv2009.1
+ Revision: 311040
- rebuild for new tcl
- add the necessary headers from Tk on-the-fly at build time
- add tcl86.patch to detect tcl 8.6, supersedes tk8.5.patch
- update to current CVS (needed for some build fixes)

* Sun Aug 17 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1.03-1mdv2009.0
+ Revision: 273094
- new version

* Wed Jul 30 2008 Thierry Vignaud <tv@mandriva.org> 1.02-19mdv2009.0
+ Revision: 254264
- rebuild

* Fri Mar 07 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1.02-17mdv2008.1
+ Revision: 181375
- rebuild

* Mon Feb 18 2008 Thierry Vignaud <tv@mandriva.org> 1.02-16mdv2008.1
+ Revision: 171005
- rebuild
- fix "foobar is blabla" summary (=> "blabla") so that it looks nice in rpmdrake
- kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Sun Sep 02 2007 Guillaume Rousse <guillomovitch@mandriva.org> 1.02-15mdv2008.0
+ Revision: 78223
- use lowercase installation directory

* Sat Sep 01 2007 Guillaume Rousse <guillomovitch@mandriva.org> 1.02-14mdv2008.0
+ Revision: 77696
- fix build with tk8.5
  ocaml policy compliance

  + Pixel <pixel@mandriva.com>
    - rebuild for ocaml 3.10.0


* Thu Jan 25 2007 Guillaume Rousse <guillomovitch@mandriva.org> 1.02-12mdv2007.0
+ Revision: 113167
- rebuild for new ocaml
- Import ocaml-lablgl

* Tue Aug 29 2006 Guillaume Rousse <guillomovitch@mandriva.org> 1.02-11mdv2007.0
- spec cleanup
- %%mkrel

* Thu Apr 27 2006 Pixel <pixel@mandriva.com> 1.02-10mdk
- rebuild for new ocaml

* Tue Jan 31 2006 Pixel <pixel@mandriva.com> 1.02-9mdk
- add BuildRequires tk-devel, tcl-devel

* Mon Jan 30 2006 Pixel <pixel@mandriva.com> 1.02-8mdk
- add BuildRequires Mesa-common-devel

* Fri Jan 27 2006 Pixel <pixel@mandriva.com> 1.02-7mdk
- add BuildRequires X11-devel

* Thu Jan 26 2006 Pixel <pixel@mandriva.com> 1.02-6mdk
- add BuildRequires camlp4

* Thu Jan 26 2006 Pixel <pixel@mandriva.com> 1.02-5mdk
- simplify BuildRequires (don't build require a file)
- only the stublibs are non-devel stuff (common mistake done in most our packages)

* Thu Jan 19 2006 Guillaume Bedot <littletux@mandriva.org> 1.02-4mdk
- Builds on x86_64

* Wed Nov 09 2005 Guillaume Bedot <littletux@mandriva.org> 1.02-3mdk
- really exclude devel files from ocaml-lablgl package

* Wed Nov 09 2005 Guillaume Bedot <littletux@mandriva.org> 1.02-2mdk
- fixed group
- source in devel package

* Wed Nov 09 2005 Guillaume Bedot <littletux@mandriva.org> 1.02-1mdk
- new release
- use bz2

* Fri Nov 04 2005 Pixel <pixel@mandriva.com> 1.01-2mdk
- rebuild for new ocaml

* Tue Nov 01 2005 Frederic Lepied <flepied@mandriva.com> 1.01-1mdk
- initial Mandriva Linux package

* Thu Jan 27 2005 Aleksey Nogin <rpm@nogin.org>
- Updated to 1.01
- Various minor spec file improvements.

